/*
	Example - simple rotations around the X-axis
	
	Assumptions are simple -- body is modeled as a set of small squares, and heat flows
	between squares based on the relative heats of the two squares and a diffusion
	function that includes a constant that models the heat conductivity of the bodies.
	
	The diffusion function mimics the error-diffusion approach of some standard halftoning
	techniques
*/
#include <GL/glut.h>
#include <stdlib.h>
#include <stdio.h>
#include <math.h>

float vp = 6.0;
GLUquadric *myQuad;

void myinit(void);
void square(void);
void display(void);
void reshape(int, int);

//new
float SphAmbDiff[4]={1.0,0.7,0.7,1.0};
GLfloat mat_specular[] = { 1.0, 0.0, 0.0, 1.0 };
GLfloat mat_shininess[] = { 50.0 };
int i;
float PI=3.141, theta=0.0;


void myinit(void)
{

//lighting
	GLfloat mat_specular[] = { 1.0, 1.0, 1.0, 1.0 };
	GLfloat mat_shininess[] = { 50.0 };
	GLfloat light_position[] = { 1.0, 1.0, 1.0, 0.0 };

	glClearColor (0.0, 0.0, 0.0, 0.0);
	glShadeModel (GL_SMOOTH);

	glMaterialfv(GL_FRONT, GL_SPECULAR, mat_specular);
	glMaterialfv(GL_FRONT, GL_SHININESS, mat_shininess);
	glLightfv(GL_LIGHT0, GL_POSITION, light_position);

	glEnable(GL_LIGHTING);
	glEnable(GL_LIGHT0);
	glEnable(GL_DEPTH_TEST);
//lighting
	
	
	glEnable (GL_DEPTH_TEST);
	glClearColor(0.0, 0.0, 1.0, 1.0); // blue background
}

void display( void )
{
//	In this example, the indentation level shows the level of activity on the transformation stack
//	The basis for this example is the unit gluSphere; everything else is done by explicit transformations
	
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);

	// these lines make the rabbit shake head like "yes, yes" ;)
	if (i++ > 360) i -= 360;
	theta = PI*i/180;
	
	glPushMatrix();
	
	//Shake head "yes, yes"
	glRotated(15.0*sin(theta), 0.0, 1.0, 0.0);

		glPushMatrix();
			//	model the head
			glColor3f(0.4, 0.4, 0.4);	//	dark gray head
			glScalef(3.0, 1.0, 1.0);
			myQuad = gluNewQuadric();
			gluSphere(myQuad, 1.0, 10, 10);
		glPopMatrix();

		glPushMatrix();

		//color of eyes, green, material spec
		//mat_specular[] = { 0.0, 0.0, 1.0, 1.0 }; //this does not work, but the following lines do
			mat_specular[0] = 0.0;
			mat_specular[1] = 1.0;
			mat_specular[2] = 0.0;
			mat_specular[3] = 1.0;
			glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE, SphAmbDiff);
			glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, mat_specular );
			glMaterialfv(GL_FRONT_AND_BACK, GL_SHININESS, mat_shininess);
		//
		//	model the left eye
		//glColor3f(0.0, 0.0, 0.0);	//	black eyes
			glTranslatef(1.0, -0.7, 0.7);
			glScalef(0.2, 0.2, 0.2);
			myQuad = gluNewQuadric();
			gluSphere(myQuad, 1.0, 10, 10);
		glPopMatrix();

		glPushMatrix();
			//	model the right eye
			glTranslatef(1.0, 0.7, 0.7);
			glScalef(0.2, 0.2, 0.2);
			myQuad = gluNewQuadric();
			gluSphere(myQuad, 1.0, 10, 10);
		glPopMatrix();


		glPushMatrix();

		//color of ears, red, material spec
			mat_specular[0] = 1.0;
			mat_specular[1] = 0.0;
			mat_specular[2] = 0.0;
			mat_specular[3] = 1.0;
			glMaterialfv(GL_FRONT_AND_BACK, GL_AMBIENT_AND_DIFFUSE, SphAmbDiff);
			glMaterialfv(GL_FRONT_AND_BACK, GL_SPECULAR, mat_specular );
			glMaterialfv(GL_FRONT_AND_BACK, GL_SHININESS, mat_shininess);
		//
		//	model the left ear
		//glColor3f(1.0, 0.6, 0.6);	//	pink ears
			glTranslatef(-1.0, -1.0, 1.0);
			glRotatef(-45.0, 1.0, 0.0, 0.0);
			glScalef(0.5, 2.0, 0.5);
			myQuad = gluNewQuadric();
			gluSphere(myQuad, 1.0, 10, 10);
		glPopMatrix();

		glPushMatrix();
			//	model the right ear
			glColor3f(1.0, 0.6, 0.6);	//	pink ears
			glTranslatef(-1.0, 1.0, 1.0);
			glRotatef(45.0, 1.0, 0.0, 0.0);
			glScalef(0.5, 2.0, 0.5);
			myQuad = gluNewQuadric();
			gluSphere(myQuad, 1.0, 10, 10);
		glPopMatrix();
	
	glutSwapBuffers();
	glPopMatrix();   //remember where the glPushMatrix() was for this?
	//} //for loop
glutPostRedisplay();
}

void reshape(int w,int h)
{
	glViewport(0,0,(GLsizei)w,(GLsizei)h);
	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(60.0, (float)w/(float)h, 1.0, 300.0);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	//           eye point     center of view       up
	gluLookAt(vp, vp/4.0, vp, 0.0, 0.0, 0.0, 0.0, 0.0, 1.0);
}

void main(int argc, char** argv)
{
/* Standard GLUT initialization */
	    glutInit(&argc,argv);
	    glutInitDisplayMode (GLUT_DOUBLE | GLUT_RGB | GLUT_DEPTH); 
	    glutInitWindowSize(500,500);
	    glutInitWindowPosition(50,50);
		glutCreateWindow("TheRabbitHead");
	    glutDisplayFunc(display);
	    glutReshapeFunc(reshape);
		
        myinit();
	    glutMainLoop(); /* enter event loop */
}